sqltriples.Types.Expression

Package sqltriples :: Module Types :: Class Expression |
[show private | hide private]
[frames | no frames]

## Class Expression

    AbstractExpression --+
                         |
                        Expression

Method Summary
| `__init__(self, expr, values, value_type)`
| `get_expression(self)`
Inherited from AbstractExpression
| ``__getitem__`(self, i)`
| ``__len__`(self)`

Generated by Epydoc 2.1 on Fri Jan 12 00:04:34 2007 | http://epydoc.sf.net